@@ -64,11 +64,10 @@ public:
 
 	Parameter & getLastControllerParam() { return last_active_controller; };
 
-	int		get_midi_channel	() { return channel; }
-	void	set_midi_channel	( int ch );
-
 	void 	generateMidiOutput	(std::vector<amsynth_midi_cc_t> &);
 
+	unsigned char assignedChannel = 0; // 0 denotes any channel
+
 private:
 	void dispatch_note(unsigned char ch,
 		       unsigned char note, unsigned char vel);
